<TS language="uk" version="2.0">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>Створити нову адресу</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Нова</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Копіювати виділену адресу в буфер обміну</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Копіювати</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>Вилучити вибрані адреси з переліку</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Видалити</translation>
    </message>
    </context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>Діалог введення паролю</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>Введіть пароль</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Новий пароль</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Повторіть пароль</translation>
    </message>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Wallet</source>
        <translation>Гаманець</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;Огляд</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>Показати стан гаманця</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;Відправити</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>&amp;Отримати</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>Переглянути історію транзакцій</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>&amp;Вихід</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>Вийти</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>&amp;Параметри...</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>Показа&amp;ти / Приховати</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>&amp;Шифрування гаманця...</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>Змінити парол&amp;ь...</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>Змінити пароль, який використовується для шифрування гаманця</translation>
    </message>
    <message>
        <source>Sign &amp;message...</source>
        <translation>&amp;Підписати повідомлення...</translation>
    </message>
    <message>
        <source>&amp;Verify message...</source>
        <translation>П&amp;еревірити повідомлення...</translation>
    </message>
    <message>
        <source>&amp;Debug window</source>
        <translation>В&amp;ікно зневадження</translation>
    </message>
    <message>
        <source>Open debugging and diagnostic console</source>
        <translation>Відкрити консоль зневадження і діагностики</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Файл</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Налаштування</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Довідка</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to the Gridcoin network</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n second(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>Синхронізовано</translation>
    </message>
    <message>
        <source>Catching up...</source>
        <translation>Синхронізується...</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>Надіслані транзакції</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>Отримані транзакції</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation>&lt;b&gt;Зашифрований&lt;/b&gt; гаманець &lt;b&gt;заблоковано&lt;/b&gt;</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Quantity:</source>
        <translation>Кількість:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>Байтів:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Сума:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Комісія:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Після комісії:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>Решта:</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Кількість</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Дата</translation>
    </message>
    <message>
        <source>Confirmations</source>
        <translation>Підтверджень</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Підтверджені</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>Редагувати адресу</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation>&amp;Мітка</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>&amp;Адреса</translation>
    </message>
    </context>
<context>
    <name>Intro</name>
    <message numerus="yes">
        <source>%n GB of free space available</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Параметри</translation>
    </message>
    <message>
        <source>&amp;Main</source>
        <translation>&amp;Головні</translation>
    </message>
    <message>
        <source>&amp;Network</source>
        <translation>&amp;Мережа</translation>
    </message>
    <message>
        <source>Map port using &amp;UPnP</source>
        <translation>Відображення порту через &amp;UPnP</translation>
    </message>
    <message>
        <source>&amp;Port:</source>
        <translation>&amp;Порт:</translation>
    </message>
    <message>
        <source>Port of the proxy (e.g. 9050)</source>
        <translation>Порт проксі-сервера (наприклад 9050)</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Вікно</translation>
    </message>
    <message>
        <source>Show only a tray icon after minimizing the window.</source>
        <translation>Показувати лише іконку в треї після згортання вікна.</translation>
    </message>
    <message>
        <source>&amp;Minimize to the tray instead of the taskbar</source>
        <translation>Мінімізувати &amp;у трей</translation>
    </message>
    <message>
        <source>M&amp;inimize on close</source>
        <translation>Згортати замість закритт&amp;я</translation>
    </message>
    <message>
        <source>&amp;Display</source>
        <translation>&amp;Відображення</translation>
    </message>
    <message>
        <source>User Interface &amp;language:</source>
        <translation>Мов&amp;а інтерфейсу користувача:</translation>
    </message>
    <message>
        <source>&amp;Unit to show amounts in:</source>
        <translation>В&amp;имірювати монети в:</translation>
    </message>
    <message>
        <source>Choose the default subdivision unit to show in the interface and when sending coins.</source>
        <translation>Виберіть одиницю вимірювання монет, яка буде відображатись в гаманці та при відправленні.</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;Гаразд</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Скасувати</translation>
    </message>
    <message>
        <source>default</source>
        <translation>типово</translation>
    </message>
    <message>
        <source>The supplied proxy address is invalid.</source>
        <translation>Невірно вказано адресу проксі.</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation>Форма</translation>
    </message>
    <message>
        <source>Available:</source>
        <translation>Наявно:</translation>
    </message>
    <message>
        <source>Your current spendable balance</source>
        <translation>Ваш поточний підтверджений баланс</translation>
    </message>
    <message>
        <source>Immature:</source>
        <translation>Незрілі:</translation>
    </message>
    <message>
        <source>Total:</source>
        <translation>Всього:</translation>
    </message>
    <message>
        <source>Your current total balance</source>
        <translation>Ваш поточний сукупний баланс</translation>
    </message>
    </context>
<context>
    <name>QObject</name>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>N/A</source>
        <translation>Н/Д</translation>
    </message>
    <message>
        <source>Client version</source>
        <translation>Версія клієнту</translation>
    </message>
    <message>
        <source>&amp;Information</source>
        <translation>&amp;Інформація</translation>
    </message>
    <message>
        <source>Startup time</source>
        <translation>Час запуску</translation>
    </message>
    <message>
        <source>Number of connections</source>
        <translation>Кількість підключень</translation>
    </message>
    <message>
        <source>Block chain</source>
        <translation>Ланцюг блоків</translation>
    </message>
    <message>
        <source>Current number of blocks</source>
        <translation>Поточне число блоків</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation>Час останнього блоку</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Відкрити</translation>
    </message>
    <message>
        <source>&amp;Clear</source>
        <translation>&amp;Очистити</translation>
    </message>
    <message>
        <source>&amp;Console</source>
        <translation>&amp;Консоль</translation>
    </message>
    <message>
        <source>&amp;Network Traffic</source>
        <translation>&amp;Мережевий трафік</translation>
    </message>
    <message>
        <source>Totals</source>
        <translation>Всього</translation>
    </message>
    <message>
        <source>In:</source>
        <translation>Вхідних:</translation>
    </message>
    <message>
        <source>Out:</source>
        <translation>Вихідних:</translation>
    </message>
    <message>
        <source>Debug log file</source>
        <translation>Файл звіту зневадження</translation>
    </message>
    <message>
        <source>Clear console</source>
        <translation>Очистити консоль</translation>
    </message>
    <message>
        <source>Use up and down arrows to navigate history, and &lt;b&gt;Ctrl-L&lt;/b&gt; to clear screen.</source>
        <translation>Використовуйте стрілки вгору вниз для навігації по історії, і &lt;b&gt;Ctrl-L&lt;/b&gt; для очищення екрана.</translation>
    </message>
    <message>
        <source>Type &lt;b&gt;help&lt;/b&gt; for an overview of available commands.</source>
        <translation>Наберіть &lt;b&gt;help&lt;/b&gt; для перегляду доступних команд.</translation>
    </message>
    <message>
        <source>%1 B</source>
        <translation>%1 Б</translation>
    </message>
    <message>
        <source>%1 KB</source>
        <translation>%1 КБ</translation>
    </message>
    <message>
        <source>%1 MB</source>
        <translation>%1 МБ</translation>
    </message>
    <message>
        <source>%1 GB</source>
        <translation>%1 ГБ</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation>Відправити</translation>
    </message>
    <message>
        <source>Inputs...</source>
        <translation>Входи...</translation>
    </message>
    <message>
        <source>automatically selected</source>
        <translation>вибираються автоматично</translation>
    </message>
    <message>
        <source>Insufficient funds!</source>
        <translation>Недостатньо коштів!</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation>Кількість:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>Байтів:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Сума:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Комісія:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Після комісії:</translation>
    </message>
    <message>
        <source>Send to multiple recipients at once</source>
        <translation>Відправити на декілька адрес</translation>
    </message>
    <message>
        <source>Add &amp;Recipient</source>
        <translation>Дод&amp;ати одержувача</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>Очистити &amp;все</translation>
    </message>
    <message>
        <source>Confirm the send action</source>
        <translation>Підтвердити відправлення</translation>
    </message>
    <message>
        <source>S&amp;end</source>
        <translation>&amp;Відправити</translation>
    </message>
    </context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation>&amp;Кількість:</translation>
    </message>
    <message>
        <source>Pay &amp;To:</source>
        <translation>&amp;Отримувач:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Повідомлення:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Мітка:</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Вставити адресу</translation>
    </message>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Signatures - Sign / Verify a Message</source>
        <translation>Підписи - Підпис / Перевірка повідомлення</translation>
    </message>
    <message>
        <source>&amp;Sign Message</source>
        <translation>&amp;Підписати повідомлення</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Вставити адресу</translation>
    </message>
    <message>
        <source>Enter the message you want to sign here</source>
        <translation>Введіть повідомлення, яке ви хочете підписати тут</translation>
    </message>
    <message>
        <source>Copy the current signature to the system clipboard</source>
        <translation>Копіювати поточну сигнатуру до системного буферу обміну</translation>
    </message>
    <message>
        <source>Sign &amp;Message</source>
        <translation>&amp;Підписати повідомлення</translation>
    </message>
    <message>
        <source>Reset all sign message fields</source>
        <translation>Скинути всі поля підпису повідомлення</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>Очистити &amp;все</translation>
    </message>
    <message>
        <source>&amp;Verify Message</source>
        <translation>П&amp;еревірити повідомлення</translation>
    </message>
    <message>
        <source>Reset all verify message fields</source>
        <translation>Скинути всі поля перевірки повідомлення</translation>
    </message>
    </context>
<context>
    <name>TransactionDesc</name>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>, broadcast through %n node(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>TransactionDescDialog</name>
    <message>
        <source>This pane shows a detailed description of the transaction</source>
        <translation>Даний діалог показує детальну статистику по вибраній транзакції</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Failed to listen on any port. Use -listen=0 if you want this.</source>
        <translation>Не вдалося слухати на жодному порту. Використовуйте -listen=0, якщо ви хочете цього.</translation>
    </message>
    <message>
        <source>Invalid -proxy address: '%s'</source>
        <translation>Помилка в адресі проксі-сервера: «%s»</translation>
    </message>
    <message>
        <source>Loading addresses...</source>
        <translation>Завантаження адрес...</translation>
    </message>
    <message>
        <source>Unknown network specified in -onlynet: '%s'</source>
        <translation>Невідома мережа вказана в -onlynet: «%s»</translation>
    </message>
    <message>
        <source>Insufficient funds</source>
        <translation>Недостатньо коштів</translation>
    </message>
    <message>
        <source>Loading block index...</source>
        <translation>Завантаження індексу блоків...</translation>
    </message>
    <message>
        <source>Loading wallet...</source>
        <translation>Завантаження гаманця...</translation>
    </message>
    <message>
        <source>Cannot write default address</source>
        <translation>Неможливо записати типову адресу</translation>
    </message>
    <message>
        <source>Rescanning...</source>
        <translation>Сканування...</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation>Завантаження завершене</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Помилка</translation>
    </message>
</context>
</TS>